==> balance_subscriber-0.0.1rc1.tar.gz: balance_subscriber-0.0.1rc1/src/balance_subscriber/__main__.py <==
import argparse
import importlib.metadata
import logging
import os
from pathlib import Path

import paho.mqtt.client

import balance_subscriber.callbacks

logger = logging.getLogger(__name__)

DESCRIPTION = """
This is an MQTT subscriber that serialises incoming messages.
"""


def get_args():
    """
    Command-line arguments
    """
    parser = argparse.ArgumentParser(description=DESCRIPTION)
    parser.add_argument(
        "--data_dir",
        type=Path,
        help="Directory to save messages to.",
        default=os.getenv("DATA_DIR"),
    )
    parser.add_argument("--verbose", "-v", action="store_true")
    parser.add_argument(
        "topics",
        nargs="*",
        help="Topics to subscribe to, default: all",
        default=os.getenv("TOPICS", "#"),
    )
    parser.add_argument(
        "--host",
        type=str,
        default=os.getenv("HOST", "localhost"),
        help="MQTT broker host",
    )
    parser.add_argument(
        "--port",
        type=int,
        default=int(os.getenv("PORT", 1883)),
        help="MQTT broker port",
    )
    parser.add_argument(
        "--keepalive",
        type=int,
        default=int(os.getenv("KEEP_ALIVE", 60)),
        help="MQTT broker keep-alive interval",
    )
    parser.add_argument(
        "--version",
        action="version",
        version=importlib.metadata.version("balance-subscriber"),
    )
    return parser.parse_args()


def get_client(topics: set[str], data_dir: Path) -> paho.mqtt.client.Client:
    if not data_dir:
        raise ValueError("No data directory specified")

    # Initialise client
    client = paho.mqtt.client.Client(paho.mqtt.client.CallbackAPIVersion.VERSION2)
    # https://eclipse.dev/paho/files/paho.mqtt.python/html/index.html#logger
    client.enable_logger()
    # Make the topics available to the on_connect callback
    client.user_data_set(dict(topics=topics, data_dir=data_dir))

    # Register callbacks
    client.on_connect = balance_subscriber.callbacks.on_connect
    client.on_message = balance_subscriber.callbacks.on_message

    return client


def main():
    args = get_args()
    logging.basicConfig(level=logging.DEBUG if args.verbose else logging.INFO)

    # Connect to message broker
    client = get_client(topics=args.topics, data_dir=args.data_dir)
    client.connect(host=args.host, port=args.port, keepalive=args.keepalive)

    # Blocking call that processes network traffic, dispatches callbacks and handles reconnecting.
    try:
        client.loop_forever()
    except KeyboardInterrupt:
        pass


if __name__ == "__main__":
    main()

==> balance_subscriber-0.1.0.tar.gz: balance_subscriber-0.1.0/src/balance_subscriber/__main__.py <==
import argparse
import importlib.metadata
import logging
import os
from pathlib import Path

from balance_subscriber.client import get_client

logger = logging.getLogger(__name__)

DESCRIPTION = """
This is an MQTT subscriber that serialises incoming messages.
"""


def get_args():
    """
    Command-line arguments
    """
    parser = argparse.ArgumentParser(description=DESCRIPTION)
    parser.add_argument(
        "--data_dir",
        "-d",
        type=Path,
        help="Directory to save messages to.",
        default=os.getenv("DATA_DIR"),
    )
    parser.add_argument(
        "--log_level",
        default=os.getenv("LOG_LEVEL", "WARNING"),
        choices=["DEBUG", "INFO", "WARNING", "ERROR", "CRITICAL"],
    )
    parser.add_argument(
        "topics",
        nargs="*",
        help="Topics to subscribe to, default: all",
        default=os.getenv("TOPICS", "#"),
    )
    parser.add_argument(
        "--host",
        type=str,
        default=os.getenv("HOST", "localhost"),
        help="MQTT broker host",
    )
    parser.add_argument(
        "--port",
        type=int,
        default=int(os.getenv("PORT", 1883)),
        help="MQTT broker port",
    )
    parser.add_argument(
        "--keepalive",
        type=int,
        default=int(os.getenv("KEEP_ALIVE", 60)),
        help="MQTT broker keep-alive interval",
    )
    parser.add_argument(
        "--encoding", default="utf-8", help="CSV output text character set"
    )
    parser.add_argument(
        "--version",
        action="version",
        version=importlib.metadata.version("balance-subscriber"),
    )
    parser.add_argument("--username", "-u", default=os.getenv("USERNAME"))
    parser.add_argument("--password", "-p", default=os.getenv("PASSWORD"))
    parser.add_argument(
        "-q", "--qos", type=int, choices={0, 1, 2}, default=0, help="Quality of service"
    )
    return parser.parse_args()


def main():
    args = get_args()
    logging.basicConfig(level=args.log_level)

    # Connect to message broker
    client = get_client(
        topics=args.topics,
        data_dir=args.data_dir,
        encoding=args.encoding,
        username=args.username,
        password=args.password,
        qos=args.qos,
    )
    client.connect(host=args.host, port=args.port, keepalive=args.keepalive)

    # Blocking call that processes network traffic, dispatches callbacks and handles reconnecting.
    try:
        client.loop_forever()
    except KeyboardInterrupt:
        pass


if __name__ == "__main__":
    main()
